@@ -6,7 +6,8 @@ on_cran <- !is_interactive && !not_cran
 if (!on_cran) {
   if (requireNamespace("spelling", quietly = TRUE)) {
     spelling::spell_check_test(
-      vignettes = TRUE, error = FALSE,
+      vignettes = TRUE,
+      error = TRUE,
       skip_on_cran = TRUE
     )
   }
